@@ -33,6 +33,7 @@ from .literals import (
 from .paginator import (
     DescribeAlarmHistoryPaginator,
     DescribeAlarmsPaginator,
+    DescribeAnomalyDetectorsPaginator,
     GetMetricDataPaginator,
     ListDashboardsPaginator,
     ListMetricsPaginator,
@@ -58,15 +59,18 @@ from .type_defs import (
     GetMetricWidgetImageOutputTypeDef,
     LabelOptionsTypeDef,
     ListDashboardsOutputTypeDef,
+    ListManagedInsightRulesOutputTypeDef,
     ListMetricsOutputTypeDef,
     ListMetricStreamsOutputTypeDef,
     ListTagsForResourceOutputTypeDef,
+    ManagedRuleTypeDef,
     MetricDataQueryTypeDef,
     MetricDatumTypeDef,
     MetricMathAnomalyDetectorTypeDef,
     MetricStreamFilterTypeDef,
     MetricStreamStatisticsConfigurationTypeDef,
     PutDashboardOutputTypeDef,
+    PutManagedInsightRulesOutputTypeDef,
     PutMetricStreamOutputTypeDef,
     SingleMetricAnomalyDetectorTypeDef,
     TagTypeDef,
@@ -415,6 +419,17 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#list_dashboards)
         """
 
+    def list_managed_insight_rules(
+        self, *, ResourceARN: str, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListManagedInsightRulesOutputTypeDef:
+        """
+        Returns a list that contains the number of managed Contributor Insights rules in
+        your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.list_managed_insight_rules)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#list_managed_insight_rules)
+        """
+
     def list_metric_streams(
         self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListMetricStreamsOutputTypeDef:
@@ -513,6 +528,17 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#put_insight_rule)
         """
 
+    def put_managed_insight_rules(
+        self, *, ManagedRules: Sequence[ManagedRuleTypeDef]
+    ) -> PutManagedInsightRulesOutputTypeDef:
+        """
+        Creates a managed Contributor Insights rule for a specified Amazon Web Services
+        resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.put_managed_insight_rules)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#put_managed_insight_rules)
+        """
+
     def put_metric_alarm(
         self,
         *,
@@ -639,6 +665,15 @@ class CloudWatchClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["describe_anomaly_detectors"]
+    ) -> DescribeAnomalyDetectorsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
