@@ -22,8 +22,7 @@ import sys
 from datetime import datetime
 from typing import Iterator, List, Sequence, Union
 
-from boto3.resources.base import ResourceMeta
-from boto3.resources.base import ServiceResource as Boto3ServiceResource
+from boto3.resources.base import ResourceMeta, ServiceResource
 from boto3.resources.collection import ResourceCollection
 
 from .client import CloudWatchClient
@@ -171,7 +170,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
         *,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionFilterTypeDef"] = ...,
+        Dimensions: Sequence[DimensionFilterTypeDef] = ...,
         NextToken: str = ...,
         RecentlyActive: Literal["PT3H"] = ...
     ) -> "ServiceResourceMetricsCollection":
@@ -226,7 +225,7 @@ class MetricAlarmsCollection(ResourceCollection):
         *,
         Statistic: StatisticType = ...,
         ExtendedStatistic: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Period: int = ...,
         Unit: StandardUnitType = ...
     ) -> "MetricAlarmsCollection":
@@ -270,7 +269,7 @@ class MetricAlarmsCollection(ResourceCollection):
         """
 
 
-class Alarm(Boto3ServiceResource):
+class Alarm(ServiceResource):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource/#alarm)
@@ -292,7 +291,7 @@ class Alarm(Boto3ServiceResource):
     namespace: str
     statistic: StatisticType
     extended_statistic: str
-    dimensions: List["DimensionTypeDef"]
+    dimensions: List[DimensionTypeDef]
     period: int
     unit: StandardUnitType
     evaluation_periods: int
@@ -301,7 +300,7 @@ class Alarm(Boto3ServiceResource):
     comparison_operator: ComparisonOperatorType
     treat_missing_data: str
     evaluate_low_sample_count_percentile: str
-    metrics: List["MetricDataQueryTypeDef"]
+    metrics: List[MetricDataQueryTypeDef]
     threshold_metric_id: str
     name: str
     metric: "Metric"
@@ -388,14 +387,14 @@ class Alarm(Boto3ServiceResource):
 _Alarm = Alarm
 
 
-class Metric(Boto3ServiceResource):
+class Metric(ServiceResource):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource/#metric)
     """
 
     metric_name: str
-    dimensions: List["DimensionTypeDef"]
+    dimensions: List[DimensionTypeDef]
     namespace: str
     name: str
     alarms: MetricAlarmsCollection
@@ -414,7 +413,7 @@ class Metric(Boto3ServiceResource):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Statistics: Sequence[StatisticType] = ...,
         ExtendedStatistics: Sequence[str] = ...,
         Unit: StandardUnitType = ...
@@ -448,15 +447,15 @@ class Metric(Boto3ServiceResource):
         InsufficientDataActions: Sequence[str] = ...,
         Statistic: StatisticType = ...,
         ExtendedStatistic: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
         Period: int = ...,
         Unit: StandardUnitType = ...,
         DatapointsToAlarm: int = ...,
         Threshold: float = ...,
         TreatMissingData: str = ...,
         EvaluateLowSampleCountPercentile: str = ...,
-        Metrics: Sequence["MetricDataQueryTypeDef"] = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Metrics: Sequence[MetricDataQueryTypeDef] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ThresholdMetricId: str = ...
     ) -> _Alarm:
         """
@@ -492,7 +491,7 @@ class CloudWatchResourceMeta(ResourceMeta):
     client: CloudWatchClient
 
 
-class CloudWatchServiceResource(Boto3ServiceResource):
+class CloudWatchServiceResource(ServiceResource):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource/)
