@@ -76,10 +76,12 @@ __all__ = (
     "GetMetricWidgetImageInputRequestTypeDef",
     "InsightRuleContributorDatapointTypeDef",
     "ListDashboardsInputRequestTypeDef",
+    "ListManagedInsightRulesInputRequestTypeDef",
     "ListMetricStreamsInputRequestTypeDef",
     "MetricStreamEntryTypeDef",
     "ListTagsForResourceInputRequestTypeDef",
     "TagTypeDef",
+    "ManagedRuleStateTypeDef",
     "StatisticSetTypeDef",
     "MetricStreamStatisticsMetricTypeDef",
     "PutDashboardInputRequestTypeDef",
@@ -107,9 +109,11 @@ __all__ = (
     "GetMetricWidgetImageOutputTypeDef",
     "ListDashboardsOutputTypeDef",
     "PutDashboardOutputTypeDef",
+    "PutManagedInsightRulesOutputTypeDef",
     "PutMetricStreamOutputTypeDef",
     "DescribeAlarmHistoryInputDescribeAlarmHistoryPaginateTypeDef",
     "DescribeAlarmsInputDescribeAlarmsPaginateTypeDef",
+    "DescribeAnomalyDetectorsInputDescribeAnomalyDetectorsPaginateTypeDef",
     "ListDashboardsInputListDashboardsPaginateTypeDef",
     "DescribeAlarmsInputAlarmExistsWaitTypeDef",
     "DescribeAlarmsInputCompositeAlarmExistsWaitTypeDef",
@@ -120,15 +124,19 @@ __all__ = (
     "InsightRuleContributorTypeDef",
     "ListMetricStreamsOutputTypeDef",
     "ListTagsForResourceOutputTypeDef",
+    "ManagedRuleTypeDef",
     "PutCompositeAlarmInputRequestTypeDef",
     "PutInsightRuleInputRequestTypeDef",
     "TagResourceInputRequestTypeDef",
+    "ManagedRuleDescriptionTypeDef",
     "MetricDatumTypeDef",
     "MetricStreamStatisticsConfigurationTypeDef",
     "ListMetricsOutputTypeDef",
     "MetricStatTypeDef",
     "GetMetricDataOutputTypeDef",
     "GetInsightRuleReportOutputTypeDef",
+    "PutManagedInsightRulesInputRequestTypeDef",
+    "ListManagedInsightRulesOutputTypeDef",
     "PutMetricDataInputRequestTypeDef",
     "GetMetricStreamOutputTypeDef",
     "PutMetricStreamInputRequestTypeDef",
@@ -360,8 +368,8 @@ DescribeInsightRulesInputRequestTypeDef = TypedDict(
     total=False,
 )
 
-InsightRuleTypeDef = TypedDict(
-    "InsightRuleTypeDef",
+_RequiredInsightRuleTypeDef = TypedDict(
+    "_RequiredInsightRuleTypeDef",
     {
         "Name": str,
         "State": str,
@@ -369,6 +377,18 @@ InsightRuleTypeDef = TypedDict(
         "Definition": str,
     },
 )
+_OptionalInsightRuleTypeDef = TypedDict(
+    "_OptionalInsightRuleTypeDef",
+    {
+        "ManagedRule": bool,
+    },
+    total=False,
+)
+
+
+class InsightRuleTypeDef(_RequiredInsightRuleTypeDef, _OptionalInsightRuleTypeDef):
+    pass
+
 
 _RequiredDimensionFilterTypeDef = TypedDict(
     "_RequiredDimensionFilterTypeDef",
@@ -549,6 +569,29 @@ ListDashboardsInputRequestTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListManagedInsightRulesInputRequestTypeDef = TypedDict(
+    "_RequiredListManagedInsightRulesInputRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+_OptionalListManagedInsightRulesInputRequestTypeDef = TypedDict(
+    "_OptionalListManagedInsightRulesInputRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListManagedInsightRulesInputRequestTypeDef(
+    _RequiredListManagedInsightRulesInputRequestTypeDef,
+    _OptionalListManagedInsightRulesInputRequestTypeDef,
+):
+    pass
+
+
 ListMetricStreamsInputRequestTypeDef = TypedDict(
     "ListMetricStreamsInputRequestTypeDef",
     {
@@ -587,6 +630,14 @@ TagTypeDef = TypedDict(
     },
 )
 
+ManagedRuleStateTypeDef = TypedDict(
+    "ManagedRuleStateTypeDef",
+    {
+        "RuleName": str,
+        "State": str,
+    },
+)
+
 StatisticSetTypeDef = TypedDict(
     "StatisticSetTypeDef",
     {
@@ -904,6 +955,14 @@ PutDashboardOutputTypeDef = TypedDict(
     },
 )
 
+PutManagedInsightRulesOutputTypeDef = TypedDict(
+    "PutManagedInsightRulesOutputTypeDef",
+    {
+        "Failures": List[PartialFailureTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 PutMetricStreamOutputTypeDef = TypedDict(
     "PutMetricStreamOutputTypeDef",
     {
@@ -941,6 +1000,18 @@ DescribeAlarmsInputDescribeAlarmsPaginateTypeDef = TypedDict(
     total=False,
 )
 
+DescribeAnomalyDetectorsInputDescribeAnomalyDetectorsPaginateTypeDef = TypedDict(
+    "DescribeAnomalyDetectorsInputDescribeAnomalyDetectorsPaginateTypeDef",
+    {
+        "Namespace": str,
+        "MetricName": str,
+        "Dimensions": Sequence[DimensionTypeDef],
+        "AnomalyDetectorTypes": Sequence[AnomalyDetectorTypeType],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 ListDashboardsInputListDashboardsPaginateTypeDef = TypedDict(
     "ListDashboardsInputListDashboardsPaginateTypeDef",
     {
@@ -1056,6 +1127,26 @@ ListTagsForResourceOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredManagedRuleTypeDef = TypedDict(
+    "_RequiredManagedRuleTypeDef",
+    {
+        "TemplateName": str,
+        "ResourceARN": str,
+    },
+)
+_OptionalManagedRuleTypeDef = TypedDict(
+    "_OptionalManagedRuleTypeDef",
+    {
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class ManagedRuleTypeDef(_RequiredManagedRuleTypeDef, _OptionalManagedRuleTypeDef):
+    pass
+
+
 _RequiredPutCompositeAlarmInputRequestTypeDef = TypedDict(
     "_RequiredPutCompositeAlarmInputRequestTypeDef",
     {
@@ -1117,6 +1208,16 @@ TagResourceInputRequestTypeDef = TypedDict(
     },
 )
 
+ManagedRuleDescriptionTypeDef = TypedDict(
+    "ManagedRuleDescriptionTypeDef",
+    {
+        "TemplateName": str,
+        "ResourceARN": str,
+        "RuleState": ManagedRuleStateTypeDef,
+    },
+    total=False,
+)
+
 _RequiredMetricDatumTypeDef = TypedDict(
     "_RequiredMetricDatumTypeDef",
     {
@@ -1204,6 +1305,22 @@ GetInsightRuleReportOutputTypeDef = TypedDict(
     },
 )
 
+PutManagedInsightRulesInputRequestTypeDef = TypedDict(
+    "PutManagedInsightRulesInputRequestTypeDef",
+    {
+        "ManagedRules": Sequence[ManagedRuleTypeDef],
+    },
+)
+
+ListManagedInsightRulesOutputTypeDef = TypedDict(
+    "ListManagedInsightRulesOutputTypeDef",
+    {
+        "ManagedRules": List[ManagedRuleDescriptionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 PutMetricDataInputRequestTypeDef = TypedDict(
     "PutMetricDataInputRequestTypeDef",
     {
